@@ -22,6 +22,7 @@ import (
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/selection"
 
 	tb "github.com/tektoncd/pipeline/internal/builder/v1beta1"
 	"github.com/tektoncd/pipeline/pkg/apis/pipeline/v1alpha1"
@@ -59,6 +60,25 @@ func TestApplyParameters(t *testing.T) {
 					tb.PipelineTaskParam("first-task-second-param", "second-value"),
 					tb.PipelineTaskParam("first-task-third-param", "static value"),
 				))),
+	}, {
+		name: "single parameter with when expression",
+		original: tb.Pipeline("test-pipeline",
+			tb.PipelineSpec(
+				tb.PipelineParamSpec("first-param", v1beta1.ParamTypeString, tb.ParamSpecDefault("default-value")),
+				tb.PipelineParamSpec("second-param", v1beta1.ParamTypeString),
+				tb.PipelineTask("first-task-1", "first-task",
+					tb.PipelineTaskWhenExpression("$(params.first-param)", selection.In, []string{"$(params.second-param)"})),
+				tb.FinalPipelineTask("final-task-1", "first-task"))),
+		run: tb.PipelineRun("test-pipeline-run",
+			tb.PipelineRunSpec("test-pipeline",
+				tb.PipelineRunParam("second-param", "second-value"))),
+		expected: tb.Pipeline("test-pipeline",
+			tb.PipelineSpec(
+				tb.PipelineParamSpec("first-param", v1beta1.ParamTypeString, tb.ParamSpecDefault("default-value")),
+				tb.PipelineParamSpec("second-param", v1beta1.ParamTypeString),
+				tb.PipelineTask("first-task-1", "first-task",
+					tb.PipelineTaskWhenExpression("default-value", selection.In, []string{"second-value"})),
+				tb.FinalPipelineTask("final-task-1", "first-task"))),
 	}, {
 		name: "pipeline parameter nested inside task parameter",
 		original: tb.Pipeline("test-pipeline",
@@ -177,7 +197,7 @@ func TestApplyTaskResults_MinimalExpression(t *testing.T) {
 		want PipelineRunState
 	}{
 		{
-			name: "Test result substitution on minimal variable substitution expression",
+			name: "Test result substitution on minimal variable substitution expression - params",
 			args: args{
 				resolvedResultRefs: ResolvedResultRefs{
 					{
@@ -227,6 +247,53 @@ func TestApplyTaskResults_MinimalExpression(t *testing.T) {
 					},
 				},
 			},
+		}, {
+			name: "Test result substitution on minimal variable substitution expression - when expressions",
+			args: args{
+				resolvedResultRefs: ResolvedResultRefs{
+					{
+						Value: v1beta1.ArrayOrString{
+							Type:      v1beta1.ParamTypeString,
+							StringVal: "aResultValue",
+						},
+						ResultReference: v1beta1.ResultRef{
+							PipelineTask: "aTask",
+							Result:       "aResult",
+						},
+						FromTaskRun: "aTaskRun",
+					},
+				},
+				targets: PipelineRunState{
+					{
+						PipelineTask: &v1beta1.PipelineTask{
+							Name:    "bTask",
+							TaskRef: &v1beta1.TaskRef{Name: "bTask"},
+							WhenExpressions: []v1beta1.WhenExpression{
+								{
+									Input:    "$(tasks.aTask.results.aResult)",
+									Operator: selection.In,
+									Values:   []string{"$(tasks.aTask.results.aResult)"},
+								},
+							},
+						},
+					},
+				},
+			},
+			want: PipelineRunState{
+				{
+					PipelineTask: &v1beta1.PipelineTask{
+						Name:    "bTask",
+						TaskRef: &v1beta1.TaskRef{Name: "bTask"},
+						WhenExpressions: []v1beta1.WhenExpression{
+							{
+								Input:    "aResultValue",
+								Operator: selection.In,
+								Values:   []string{"aResultValue"},
+							},
+						},
+					},
+				},
+			},
 		},
 	}
 	for _, tt := range tests {
@@ -250,7 +317,7 @@ func TestApplyTaskResults_EmbeddedExpression(t *testing.T) {
 		want PipelineRunState
 	}{
 		{
-			name: "Test result substitution on embedded variable substitution expression",
+			name: "Test result substitution on embedded variable substitution expression - params",
 			args: args{
 				resolvedResultRefs: ResolvedResultRefs{
 					{
@@ -300,6 +367,53 @@ func TestApplyTaskResults_EmbeddedExpression(t *testing.T) {
 					},
 				},
 			},
+		}, {
+			name: "Test result substitution on embedded variable substitution expression - when expressions",
+			args: args{
+				resolvedResultRefs: ResolvedResultRefs{
+					{
+						Value: v1beta1.ArrayOrString{
+							Type:      v1beta1.ParamTypeString,
+							StringVal: "aResultValue",
+						},
+						ResultReference: v1beta1.ResultRef{
+							PipelineTask: "aTask",
+							Result:       "aResult",
+						},
+						FromTaskRun: "aTaskRun",
+					},
+				},
+				targets: PipelineRunState{
+					{
+						PipelineTask: &v1beta1.PipelineTask{
+							Name:    "bTask",
+							TaskRef: &v1beta1.TaskRef{Name: "bTask"},
+							WhenExpressions: []v1beta1.WhenExpression{
+								{
+									Input:    "Result value --> $(tasks.aTask.results.aResult)",
+									Operator: selection.In,
+									Values:   []string{"Result value --> $(tasks.aTask.results.aResult)"},
+								},
+							},
+						},
+					},
+				},
+			},
+			want: PipelineRunState{
+				{
+					PipelineTask: &v1beta1.PipelineTask{
+						Name:    "bTask",
+						TaskRef: &v1beta1.TaskRef{Name: "bTask"},
+						WhenExpressions: []v1beta1.WhenExpression{
+							{
+								Input:    "Result value --> aResultValue",
+								Operator: selection.In,
+								Values:   []string{"Result value --> aResultValue"},
+							},
+						},
+					},
+				},
+			},
 		},
 	}
 	for _, tt := range tests {
@@ -451,6 +565,19 @@ func TestContext(t *testing.T) {
 				tb.PipelineTask("first-task-1", "first-task",
 					tb.PipelineTaskParam("first-task-first-param", "pipelineRunName-1"),
 				))),
+	}, {
+		description: "context pipelineRunNameNamespace replacement with defined pipelineRunNamepsace in spec",
+		pr:          tb.PipelineRun("pipelineRunName", tb.PipelineRunNamespace("prns")),
+		original: tb.Pipeline("test-pipeline",
+			tb.PipelineSpec(
+				tb.PipelineTask("first-task-1", "first-task",
+					tb.PipelineTaskParam("first-task-first-param", "$(context.pipelineRun.namespace)-1"),
+				))),
+		expected: tb.Pipeline("test-pipeline",
+			tb.PipelineSpec(
+				tb.PipelineTask("first-task-1", "first-task",
+					tb.PipelineTaskParam("first-task-first-param", "prns-1"),
+				))),
 	}, {
 		description: "context pipelineRunName replacement with no defined pipeline in spec",
 		pr:          &v1beta1.PipelineRun{},
@@ -464,6 +591,36 @@ func TestContext(t *testing.T) {
 				tb.PipelineTask("first-task-1", "first-task",
 					tb.PipelineTaskParam("first-task-first-param", "-1"),
 				))),
+	}, {
+		description: "context pipelineRunNamespace replacement with no defined pipelineRunNamespace in spec",
+		pr:          tb.PipelineRun("pipelineRunName"),
+		original: tb.Pipeline("test-pipeline",
+			tb.PipelineSpec(
+				tb.PipelineTask("first-task-1", "first-task",
+					tb.PipelineTaskParam("first-task-first-param", "$(context.pipelineRun.namespace)-1"),
+				))),
+		expected: tb.Pipeline("test-pipeline",
+			tb.PipelineSpec(
+				tb.PipelineTask("first-task-1", "first-task",
+					tb.PipelineTaskParam("first-task-first-param", "-1"),
+				))),
+	}, {
+		description: "context pipeline name replacement with pipelinerun uid",
+		pr: &v1beta1.PipelineRun{
+			ObjectMeta: metav1.ObjectMeta{
+				UID: "UID-1",
+			},
+		},
+		original: tb.Pipeline("test-pipeline",
+			tb.PipelineSpec(
+				tb.PipelineTask("first-task-1", "first-task",
+					tb.PipelineTaskParam("first-task-first-param", "$(context.pipelineRun.uid)"),
+				))),
+		expected: tb.Pipeline("test-pipeline",
+			tb.PipelineSpec(
+				tb.PipelineTask("first-task-1", "first-task",
+					tb.PipelineTaskParam("first-task-first-param", "UID-1"),
+				))),
 	}} {
 		t.Run(tc.description, func(t *testing.T) {
 			got := ApplyContexts(&tc.original.Spec, tc.original.Name, tc.pr)
